@@ -10,6 +10,11 @@ with_mock_crunch({
         expect_identical(groups(ds), list())
         expect_identical(name(ds), "test ds")
     })
+    test_that("group_by errors if assigned columns not in dataset", {
+        expect_error(group_by(ds, catfish), "catfish is not present in the Dataset")
+        expect_error(group_by(ds, catfish, dogfish), 
+            "catfish, dogfish are not present in the Dataset")
+    })
 
     ds2 <- group_by(ds, gender)
     test_that("group_by returns a GroupedCrunchDataset", {
@@ -55,4 +60,8 @@ with_mock_crunch({
         expect_identical(groupVars(select(ds2, birthyr, gender, starttime)),
             "gender")
     })
+    test_that("Grouping helpers work on CrunchDatasets", {
+        expect_null(group_vars(ds))
+        expect_identical(tbl_vars(ds), names(ds))
+    })
 })
